@@ -6,6 +6,8 @@ from firebase_admin import firestore
 from flask import request, abort
 from os import getenv
 import logging
+import base64
+import ast
 
 logger = logging.getLogger("ace_authorize")
 handler = StreamHandler()
@@ -37,9 +39,8 @@ def get_scopes(tenant_id=None):
     if 'X-Apigateway-Api-Userinfo' in request.headers:
         auth_header = request.headers.get('X-Apigateway-Api-Userinfo')
         jwt_header = base64.urlsafe_b64decode(auth_header + '=' * (4 - len(auth_header) % 4))
-        decoded_jwt_header = jwt_header.decode("UTF-8")
-        decoded_token = ast.literal_eval(decoded_jwt_header)
-    else:
+        decoded_token = jwt_header.decode("UTF-8")
+    if 'Authorization' in request.headers:
         auth_header = request.headers.get('Authorization')
         auth_header = auth_header.rpartition(' ')[2]
         decoded_token = jwt.decode(auth_header, options={"verify_signature": False})
